==> colour-science-0.3.8-py27_0.tar.bz2: Lib/site-packages/colour/models/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import

from .cie_xyy import (
    XYZ_to_xyY,
    xyY_to_XYZ,
    xy_to_xyY,
    xyY_to_xy,
    xy_to_XYZ,
    XYZ_to_xy)
from .cie_lab import XYZ_to_Lab, Lab_to_XYZ, Lab_to_LCHab, LCHab_to_Lab
from .cie_luv import (
    XYZ_to_Luv,
    Luv_to_XYZ,
    Luv_to_uv,
    Luv_uv_to_xy,
    Luv_to_LCHuv,
    LCHuv_to_Luv)
from .cie_ucs import XYZ_to_UCS, UCS_to_XYZ, UCS_to_uv, UCS_uv_to_xy
from .cie_uvw import XYZ_to_UVW
from .hunter_lab import (
    XYZ_to_K_ab_HunterLab1966,
    XYZ_to_Hunter_Lab,
    Hunter_Lab_to_XYZ)
from .hunter_rdab import XYZ_to_Hunter_Rdab
from .ipt import XYZ_to_IPT, IPT_to_XYZ, IPT_hue_angle
from .common import (
    COLOURSPACE_MODELS,
    COLOURSPACE_MODELS_LABELS,
    XYZ_to_colourspace_model)
from .dataset import *  # noqa
from . import dataset
from .rgb import *  # noqa
from . import rgb

__all__ = ['XYZ_to_xyY',
           'xyY_to_XYZ',
           'xy_to_xyY',
           'xyY_to_xy',
           'xy_to_XYZ',
           'XYZ_to_xy']
__all__ += ['XYZ_to_Lab', 'Lab_to_XYZ', 'Lab_to_LCHab', 'LCHab_to_Lab']
__all__ += ['XYZ_to_Luv',
            'Luv_to_XYZ',
            'Luv_to_uv',
            'Luv_uv_to_xy',
            'Luv_to_LCHuv',
            'LCHuv_to_Luv']
__all__ += ['XYZ_to_UCS', 'UCS_to_XYZ', 'UCS_to_uv', 'UCS_uv_to_xy']
__all__ += ['XYZ_to_UVW']
__all__ += ['XYZ_to_K_ab_HunterLab1966',
            'XYZ_to_Hunter_Lab',
            'Hunter_Lab_to_XYZ',
            'XYZ_to_Hunter_Rdab']
__all__ += ['XYZ_to_Hunter_Rdab']
__all__ += ['XYZ_to_IPT', 'IPT_to_XYZ', 'IPT_hue_angle']
__all__ += ['COLOURSPACE_MODELS',
            'COLOURSPACE_MODELS_LABELS',
            'XYZ_to_colourspace_model']
__all__ += dataset.__all__
__all__ += rgb.__all__

==> colour-science-0.3.9-py36_0.tar.bz2: Lib/site-packages/colour/models/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import

from .cie_xyy import (
    XYZ_to_xyY,
    xyY_to_XYZ,
    xy_to_xyY,
    xyY_to_xy,
    xy_to_XYZ,
    XYZ_to_xy)
from .cie_lab import XYZ_to_Lab, Lab_to_XYZ, Lab_to_LCHab, LCHab_to_Lab
from .cie_luv import (
    XYZ_to_Luv,
    Luv_to_XYZ,
    Luv_to_uv,
    Luv_uv_to_xy,
    Luv_to_LCHuv,
    LCHuv_to_Luv)
from .cie_ucs import XYZ_to_UCS, UCS_to_XYZ, UCS_to_uv, UCS_uv_to_xy
from .cie_uvw import XYZ_to_UVW
from .hunter_lab import (
    XYZ_to_K_ab_HunterLab1966,
    XYZ_to_Hunter_Lab,
    Hunter_Lab_to_XYZ)
from .hunter_rdab import XYZ_to_Hunter_Rdab
from .ipt import XYZ_to_IPT, IPT_to_XYZ, IPT_hue_angle
from .ucs_luo2006 import (
    JMh_CIECAM02_to_CAM02LCD,
    CAM02LCD_to_JMh_CIECAM02,
    JMh_CIECAM02_to_CAM02SCD,
    CAM02SCD_to_JMh_CIECAM02,
    JMh_CIECAM02_to_CAM02UCS,
    CAM02UCS_to_JMh_CIECAM02)
from .common import (
    COLOURSPACE_MODELS,
    COLOURSPACE_MODELS_LABELS,
    XYZ_to_colourspace_model)
from .dataset import *  # noqa
from . import dataset
from .rgb import *  # noqa
from . import rgb

__all__ = ['XYZ_to_xyY',
           'xyY_to_XYZ',
           'xy_to_xyY',
           'xyY_to_xy',
           'xy_to_XYZ',
           'XYZ_to_xy']
__all__ += ['XYZ_to_Lab', 'Lab_to_XYZ', 'Lab_to_LCHab', 'LCHab_to_Lab']
__all__ += ['XYZ_to_Luv',
            'Luv_to_XYZ',
            'Luv_to_uv',
            'Luv_uv_to_xy',
            'Luv_to_LCHuv',
            'LCHuv_to_Luv']
__all__ += ['XYZ_to_UCS', 'UCS_to_XYZ', 'UCS_to_uv', 'UCS_uv_to_xy']
__all__ += ['XYZ_to_UVW']
__all__ += ['XYZ_to_K_ab_HunterLab1966',
            'XYZ_to_Hunter_Lab',
            'Hunter_Lab_to_XYZ',
            'XYZ_to_Hunter_Rdab']
__all__ += ['XYZ_to_Hunter_Rdab']
__all__ += ['XYZ_to_IPT', 'IPT_to_XYZ', 'IPT_hue_angle']
__all__ += ['JMh_CIECAM02_to_CAM02LCD',
            'CAM02LCD_to_JMh_CIECAM02',
            'JMh_CIECAM02_to_CAM02SCD',
            'CAM02SCD_to_JMh_CIECAM02',
            'JMh_CIECAM02_to_CAM02UCS',
            'CAM02UCS_to_JMh_CIECAM02']
__all__ += ['COLOURSPACE_MODELS',
            'COLOURSPACE_MODELS_LABELS',
            'XYZ_to_colourspace_model']
__all__ += dataset.__all__
__all__ += rgb.__all__
